==> kpeggy-0.2.tar.gz: kpeggy-0.2/kpeggy/astardata.h <==
/***************************************************************************
                          astardata.h  -  description
                             -------------------
    begin                : Wed Nov 14 2001
    copyright            : (C) 2001 by Jos?Pablo Fern?dez
    email                : jpablo@localhost.localdomain
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ASTARDATA_H
#define ASTARDATA_H

/**
  *@author Jos?Pablo Fern?dez
  */

#include "tree.h"


class AStarData   {
public: 
	AStarData() { g = 0 ;h = 0 ;}
	virtual ~AStarData(void) { }

   virtual Tree<AStarData> *sucesors(void) { return null ;}
	virtual bool isGoal(void) {return false ; }
	virtual void init(void) { }
	virtual bool isEqual(AStarData data) { return false ;}
	int get_g() 	{ return g; }
	void set_g(int g)  { AStarData::g = g;}
	void set_h(int h) { AStarData::h = h;}
	int get_h() {return h; }
	int g ;
	int h ;	

};

#endif

==> kpeggy-0.3.tar.gz: kpeggy-0.3/kpeggy/astardata.h <==
/***************************************************************************
                          astardata.h  -  description
                             -------------------
    begin                : Wed Nov 14 2001
    copyright            : (C) 2001 by Jos Pablo Fernndez
    email                : jpablo@di.uc3m.es
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ASTARDATA_H
#define ASTARDATA_H

/**
  *@author Jos Pablo Fernndez
  */

#include <qlist.h>

#include "tree.h"


class AStarData   {
public: 
	AStarData() { g = 0 ;h = 0 ;}
	AStarData(AStarData &data) {} ;	
	virtual ~AStarData(void) { }

	virtual Tree<AStarData> *sucesors(void) { return null ;}
	virtual bool isGoal(void) {return false ; }
	virtual void init(void) { }
	virtual bool isEqual(AStarData data) { return false ;}
	int get_g() 	{ return g; }
	void set_g(int g)  { AStarData::g = g;}
	void set_h(int h) { AStarData::h = h;}
	int get_h() {return h; }

private:
	int g ;
	int h ;	

};

#endif
